// antmh.hh -- a class for handling serial lines.
// Copyright (C) 1995 Ari Mujunen. (amn@nfra.nl, Ari.Mujunen@hut.fi)

// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License.
// See the file 'COPYING' for details.

/* $Log$
 */


#ifndef _antmh_hh
#ifdef __GNUG__
#pragma interface
#endif
#define _antmh_hh 1

#include "registration.h"
RCSID(antmh_hh, "$Id$");


  /* Command characters ('Co') to 'VLBI_TRACKER' in VAX. */
typedef enum {
  cCoSendTime='1',
  cCoTrack='2',
  cCoCheckPointing='3',
  cCoStopTracking='4'
} tCommandCharacters;

  /* Antenna status response integer codes ('St') from 'VLBI_TRACKER'. */
typedef enum {
  cStStandby=1,
  cStSlewing=2,
  cStTracking=3,
  cStLimits=4,
  cStDeviceError=5,  /* ??? VLBI_TRACKER wants to report something odd */
  cStLastDefinedCode=cStDeviceError,
  cStTimeGiven=0,
  cStNoResponse=-1  /* serial communication is out of sync */
} tAntennaStatus;


  /* Returns antenna status from the latest antenna operation. */
  /* Useful in continuously updating displays etc. */
tAntennaStatus fPeekAntennaStatus(void);

  /* Gets a "fresh" antenna status from antenna control computer. */
tAntennaStatus fQueryAntennaStatus(void);

  /* Returns a textual explanation of a status code */
  /* of a given maximum length (must be 2 or more characters). */
char *fDecodeAntennaStatus(
  int status,
  int maxLength
);

  /* One can always ask the UTC time from antenna computer. */
tAntennaStatus fGetTimeFromAntennaComputer(
  char *timeString
);

  /* Start/stop tracking a ra/decl source. */
tAntennaStatus fTrackASource(
  double ra,
  double decl
);
tAntennaStatus fCheckPointing(void);
tAntennaStatus fStopTracking(void);


/* FS9 interface routines. */
void
fsAntOpen( char *path);

int  /* 0==successful */
fsStartTracking(char *lsorna,
		double ra50, double dec50, double ep1950,
		double radat, double decdat, double epoch);

void
fsGotoIdle(void);

void
fsUpdateOffsets(double raOff, double decOff,
		double azOff, double elOff, 
		double xOff, double xOff);

/* Returns 1 only iff on source, status strings in '*buf'. */
int
fsOnsource(char *buf, char *verboseBuf);

#endif
